@@ -5,37 +5,32 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef FINDTHISDEVICEPLUGIN_H
-#define FINDTHISDEVICEPLUGIN_H
+#pragma once
 
 #include <core/kdeconnectplugin.h>
 
 #ifdef Q_OS_WIN
+#include <QDebug>
 #include <Windows.h>
 #define INFO_BUFFER_SIZE 32767
 #else
-#include <QStandardPaths>
 #include <QFile>
+#include <QStandardPaths>
 #include <QUrl>
 #endif
-// Qt
-#include "plugin_findthisdevice_debug.h"
 
 #define PACKET_TYPE_FINDMYPHONE_REQUEST QStringLiteral("kdeconnect.findmyphone.request")
 
-class FindThisDevicePlugin
-    : public KdeConnectPlugin
+class FindThisDevicePlugin : public KdeConnectPlugin
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.kdeconnect.device.findthisdevice")
 
 public:
-    explicit FindThisDevicePlugin(QObject* parent, const QVariantList& args);
-    ~FindThisDevicePlugin() override;
+    using KdeConnectPlugin::KdeConnectPlugin;
 
-    void connected() override {};
     QString dbusPath() const override;
-    bool receivePacket(const NetworkPacket& np) override;
+    void receivePacket(const NetworkPacket &np) override;
 };
 
 inline QString defaultSound()
@@ -44,32 +39,26 @@ inline QString defaultSound()
     QUrl soundURL;
 #ifdef Q_OS_WIN
     wchar_t infoBuf[INFO_BUFFER_SIZE];
-    if(!GetWindowsDirectory(infoBuf, INFO_BUFFER_SIZE)) {
-        qCWarning(KDECONNECT_PLUGIN_FINDTHISDEVICE) << "Error with getting the Windows Directory.";
+    if (!GetWindowsDirectory(infoBuf, INFO_BUFFER_SIZE)) {
+        qWarning() << "Error with getting the Windows Directory.";
     } else {
         dirPath = QString::fromStdWString(infoBuf) + QStringLiteral("/media");
         if (!dirPath.isEmpty()) {
-            soundURL = QUrl::fromUserInput(QStringLiteral("Ring01.wav"),
-                                            dirPath,
-                                            QUrl::AssumeLocalFile);
+            soundURL = QUrl::fromUserInput(QStringLiteral("Ring01.wav"), dirPath, QUrl::AssumeLocalFile);
         }
     }
 #else
     const QStringList dataLocations = QStandardPaths::standardLocations(QStandardPaths::GenericDataLocation);
     for (const QString &dataLocation : dataLocations) {
         dirPath = dataLocation + QStringLiteral("/sounds");
-        soundURL = QUrl::fromUserInput(QStringLiteral("Oxygen-Im-Phone-Ring.ogg"),
-                                        dirPath,
-                                        QUrl::AssumeLocalFile);
+        soundURL = QUrl::fromUserInput(QStringLiteral("Oxygen-Im-Phone-Ring.ogg"), dirPath, QUrl::AssumeLocalFile);
         if ((soundURL.isLocalFile() && soundURL.isValid() && QFile::exists(soundURL.toLocalFile()))) {
             break;
         }
     }
 #endif
     if (soundURL.isEmpty()) {
-        qCWarning(KDECONNECT_PLUGIN_FINDTHISDEVICE) << "Could not find default ring tone.";
+        qWarning() << "Could not find default ring tone.";
     }
     return soundURL.toLocalFile();
 }
-
-#endif //FINDTHISDEVICEPLUGIN_H
